@@ -12,8 +12,8 @@ print.quantmodEnv <- function(x, ...) {
 }
 
 .onAttach <- function(libname,pkgname) {
-  msg <- "Version 0.4-0 included new data defaults. See ?getSymbols."
-  packageStartupMessage(msg)
+  #msg <- "Version 0.4-0 included new data defaults. See ?getSymbols."
+  #packageStartupMessage(msg)
   # --as-cran check is complaining of this, as a NOTE
   #attach(NULL, name='.quantmodEnv')  
 }
